summaryrefslogtreecommitdiffstats
path: root/tdecore/ksimpleconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/ksimpleconfig.h')
-rw-r--r--tdecore/ksimpleconfig.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdecore/ksimpleconfig.h b/tdecore/ksimpleconfig.h
index c7efeecfa..326fc8094 100644
--- a/tdecore/ksimpleconfig.h
+++ b/tdecore/ksimpleconfig.h
@@ -28,17 +28,17 @@ class KSimpleConfigPrivate;
/**
* KDE Configuration entries
*
* This is a trivial extension of KConfig for applications that need
* only one configuration file and no default system.
* A difference with KConfig is that when the data in memory is written back
* it is not merged with what is on disk.
* Whatever is in memory simply replaces what is on disk entirely.
*
* @author Kalle Dalheimer <kalle@kde.org>, Preston Brown <pbrown@kde.org>
- * @see KConfigBase KConfig
+ * @see TDEConfigBase TDEConfig
* @short KDE Configuration Management class with deletion ability
*/
-class TDECORE_EXPORT KSimpleConfig : public KConfig
+class TDECORE_EXPORT KSimpleConfig : public TDEConfig
{
Q_OBJECT
@@ -55,7 +55,7 @@ public:
*/
KSimpleConfig( const TQString &fileName, bool bReadOnly = false);
- KSimpleConfig(KConfigBackEnd *backEnd, bool bReadOnly = false);
+ KSimpleConfig(TDEConfigBackEnd *backEnd, bool bReadOnly = false);
/**
* Destructor.
@@ -28,17 +28,17 @@ class KSimpleConfigPrivate;
* KDE Configuration entries
*
- * This is a trivial extension of KConfig for applications that need
+ * This is a trivial extension of TDEConfig for applications that need
* only one configuration file and no default system.
@@ -28,17 +28,17 @@ class KSimpleConfigPrivate;
* only one configuration file and no default system.
- * A difference with KConfig is that when the data in memory is written back
+ * A difference with TDEConfig is that when the data in memory is written back
* it is not merged with what is on disk.
* Whatever is in memory simply replaces what is on disk entirely.